pub struct TrashData();Expand description
Storage map used for wasting proof size.
It contains no meaningful data - hence the name “Trash”. The maximal number of entries is set to 65k, which is just below the next jump at 16^4. This is important to reduce the proof size benchmarking overestimate. The assumption here is that we won’t have more than 65k * 1KiB = 65MiB of proof size wasting in practice. However, this limit is not enforced, so the pallet would also work out of the box with more entries, but its benchmarked proof weight would possibly be underestimated in that case.
Warning: Doc-Only
This type is automatically generated, and is doc-only. See the real version in
[pallet::TrashData].